# Copyright (c) 2018 SUSE LLC.
#  All Rights Reserved.

#  This program is free software; you can redistribute it and/or
#  modify it under the terms of version 2 or 3 of the GNU General
#  Public License as published by the Free Software Foundation.

#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.   See the
#  GNU General Public License for more details.

#  You should have received a copy of the GNU General Public License
#  along with this program; if not, contact SUSE LLC.

#  To contact SUSE about this file by physical or electronic mail,
#  you may find current contact information at www.suse.com

require 'ui/event_dispatcher'
require 'rmt/ssl/certificate_generator'
require 'rmt/utils'
require 'y2firewall/firewalld'

module RMT; end

class RMT::WizardFinalPage < Yast::Client
  include ::UI::EventDispatcher

  Yast.import 'Report'
  Yast.import 'Service'

  def initialize(config)
    textdomain 'rmt'
    @config = config
  end

  def render_content
    Wizard.SetNextButton(:next, Label.FinishButton)

    contents = HBox(
      HStretch(),
      VBox(
        Left(Heading(_('Configuration Summary'))),
        VBox(
          VSpacing(1),
          Left(Heading(_('SCC Organization:'))),
          Left(Label(@config['scc']['username'])),
          VSpacing(1),
          Left(Heading(_('RMT Config File Path:'))),
          Left(Label(RMT::Utils::CONFIG_FILENAME.to_s)),
          VSpacing(1),
          Left(Heading(_('SSL Certificate Path:'))),
          Left(Label(RMT::SSL::CertificateGenerator::RMT_SSL_DIR.to_s)),
          VSpacing(1),
          Left(Heading(_('Database Username:'))),
          Left(Label(@config['database']['username'])),
          VSpacing(1),
          Left(Heading(_('Firewall:'))),
          Left(Label(RMT::WizardFirewallPage::FirewallWidget.new.status_label))
        )
      ),
      HStretch()
    )

    Wizard.SetContents(
      _('RMT Configuration - Summary'),
      contents,
      _('<p>This is a list of all RMT configuration performed by this wizard.</p><p>Please check for anything that is incorrect.</p>'),
      true,
      true
    )
  end

  def next_handler
    finish_dialog(:next)
  end

  def abort_handler
    finish_dialog(:abort)
  end

  def back_handler
    finish_dialog(:back)
  end

  def run
    render_content
    event_loop
  end
end
